asr.database.totree
===================

.. automodule:: asr.database.totree

   
   
   .. rubric:: Functions

   
   .. autofunction:: make_folder_dict
   .. autofunction:: make_folder_tree
   
   

   
   
   

   
   
   